import { ElMessage } from 'element-plus';
import request from '/@/utils/request';
/**
 * @summary 获取最近一条记录
 */
export const GetLastRecord = async (params, req = request) => {
	return req({
		url: '/Monitor/Record/Std/GetLastRecord@V2.0',
		method: 'GET',
		params: params,
	});
};

/**
 * 调用接口，返回最近一个测点的记录
 * 报错时返回 undefined
 * @returns
 */
export const getLastRecordStd = async (params, req: any = request) => {
	const res = await GetLastRecord(params, req);

	if (res?.Code === 0) {
		const resData = res.Data as any;
		return resData;
	} else {
		ElMessage.error('获取测点记录失败' + (res?.Message ? `，${JSON.stringify(res.Message)}` : ''));
		return undefined;
	}
};

/**
 * @summary 获取最近的多个测点的记录
 */
export const GetLastRecordListStd = async (params, req: any = request) => {
	return req({
		url: '/Monitor/Record/Std/GetLastRecordList@V2.0',
		method: 'GET',
		params,
	});
};

/**
 * 调用接口，返回最近的多个测点的记录
 * 报错时返回 undefined
 * @returns
 */
export const getLastRecordListStd = async (params, req: any = request) => {
	const res = await GetLastRecordListStd(params, req);

	if (res?.Code === 0) {
		const resData = (res.Data || []) as any[];
		return resData;
	} else {
		ElMessage.error('获取测点记录失败' + (res?.Message ? `，${JSON.stringify(res.Message)}` : ''));
		return undefined;
	}
};
